import { Db } from 'mongodb';
import { getDb } from '../migrations-utils/db';

export const up = async () => {
  try {
    const db: Db = await getDb();

    // Update labels of freeness
    const cursor = db.collection('categories').find({ id: 'freeWorkShop' });
    let category;
    while ((category = await cursor.next())) {
      const modules = [
        {
          id: 'yes',
          name: 'Gratuit',
        },
        {
          id: 'underCondition',
          name: 'Gratuit sous conditions',
        },
        {
          id: 'no',
          name: 'Payant',
        },
      ];

      await db.collection('categories').updateOne(
        { _id: category._id },
        {
          $set: { modules: modules },
        }
      );
    }

    // Adds the field for the condition of freeness
    await db.collection('structures').updateMany({}, { $set: { 'categories.freenessCondition': null } });

    console.log(
      `Update done: freeWorkShops labels changed and 'freenessCondition' field added to all documents in 'structures' collection.`
    );
  } catch (error) {
    console.error('Error while changing freeWorkShops labels:', error);
  }
};

export const down = async () => {
  try {
    const db: Db = await getDb();

    const cursor = db.collection('categories').find({ id: 'freeWorkShop' });
    let category;
    while ((category = await cursor.next())) {
      const modules = [
        {
          id: 'yes',
          name: 'Accompagnements gratuits',
        },
        {
          id: 'underCondition',
          name: 'Accompagnements gratuits sous conditions',
        },
        {
          id: 'no',
          name: 'Accompagnements payants',
        },
      ];

      await db.collection('categories').updateOne(
        { _id: category._id },
        {
          $set: { modules: modules },
        }
      );
    }

    // Removes the field for the condition of freeness
    await db.collection('structures').updateMany({}, { $unset: { 'categories.freenessCondition': '' } });

    console.log(`Downgrade done: 'freenessCondition' field removed from all documents in 'structures' collection.`);
  } catch (error) {
    console.error('Error reverting freeWorkShop ids:', error);
  }
};
